import json
from pathlib import Path

import pytest


@pytest.fixture
def user_filesystem(tmp_path):
    base_dir = Path(tmp_path)
    home_dir = base_dir / "home_dir"
    home_dir.mkdir(parents=True, exist_ok=True)
    cwd_dir = base_dir / "cwd_dir"
    cwd_dir.mkdir(parents=True, exist_ok=True)

    home_config_data = {"username": "home_username", "email": "home@email.com"}
    with open(home_dir / "diffpyconfig.json", "w") as f:
        json.dump(home_config_data, f)

    yield tmp_path



#!/usr/bin/env python
##############################################################################
#
# (c) 2024 The Trustees of Columbia University in the City of New York.
# All rights reserved.
#
# File coded by: Billinge Group members and community contributors.
#
# See GitHub contributions for a more detailed list of contributors.
# https://github.com/bobleesj-test-org/bobleesj.release/graphs/contributors
#
# See LICENSE.rst for license information.
#
##############################################################################

"""Python package for doing science."""

# package version
from bobleesj.release.version import __version__

# silence the pyflakes syntax checker
assert __version__ or True

# End of file



#!/usr/bin/env python
##############################################################################
#
# (c) 2024 The Trustees of Columbia University in the City of New York.
# All rights reserved.
#
# File coded by: Billinge Group members and community contributors.
#
# See GitHub contributions for a more detailed list of contributors.
# https://github.com/bobleesj-test-org/bobleesj.release/graphs/contributors
#
# See LICENSE.rst for license information.
#
##############################################################################

"""Blank namespace package for module bobleesj."""


from pkgutil import extend_path

__path__ = extend_path(__path__, __name__)

# End of file




"""Unit tests for __version__.py
"""

import bobleesj.release


def test_package_version():
    """Ensure the package version is defined and not set to the initial placeholder."""
    assert hasattr(bobleesj.release, "__version__")
    assert bobleesj.release.__version__ != "0.0.0"
